APK files are an archive file in `ZIP` format based on the JAR file format. The APK file usually contains the following directories:

*   `META-INF` directory:
    *   `MANIFEST.MF`: the manifest file
    *   `CERT.RSA` or `CERT.DSA`: the certificate of the application
    *   `CERT.SF`: list of ressources and `SHA-1` digest
*   `lib`: directory containing compiled code. The directory is split into more directories for each processor architecture (`x86`, `x86_64`, `armeabi`, `arm64-v8a` ...)
*   `res`: directory containing not compiled resources
*   `assets`: directory containing application assets
*   `AndroidManifest.xml`: binary XML file describing the application (permissions, version, libraries ...)
*   `classes.dex`: file in the `DEX` file format containing compiled Java code
*   `resources.arsc`: file containing precompiled resources